@@ -1,4 +1,5 @@
 use binance::api::*;
+use binance::savings::*;
 use binance::config::*;
 use binance::general::*;
 use binance::account::*;
@@ -15,9 +16,10 @@ fn main() {
     // The market data API endpoint
     market_data();
 
-    // The account data API endpoint examples need an API key. Change those lines locally
+    // The account data API and savings API endpoint examples need an API key. Change those lines locally
     // and uncomment the line below (and do not commit your api key :)).
     //account();
+    //savings();
 }
 
 fn general(use_testnet: bool) {
@@ -131,6 +133,29 @@ fn account() {
     }
 }
 
+#[allow(dead_code)]
+fn savings() {
+    let api_key = Some("YOUR_API_KEY".into());
+    let api_secret = Some("YOUR_SECRET_KEY".into());
+
+    let savings: Savings = Binance::new(api_key, api_secret);
+
+    match savings.get_all_coins() {
+        Ok(answer) => println!("{:#?}", answer),
+        Err(e) => println!("Error: {}", e),
+    }
+
+    match savings.asset_detail(None) {
+        Ok(answer) => println!("{:#?}", answer),
+        Err(e) => println!("Error: {}", e),
+    }
+
+    match savings.deposit_address("BTC", None) {
+        Ok(answer) => println!("{:#?}", answer),
+        Err(e) => println!("Error: {:?}", e),
+    }
+}
+
 #[allow(dead_code)]
 fn market_data() {
     let market: Market = Binance::new(None, None);
