@@ -772,6 +772,87 @@ pub struct DepthOrderBookEvent {
     pub asks: Vec<Asks>,
 }
 
+/// Response to the Savings API get all coins request
+#[derive(Debug, Serialize, Deserialize, Clone)]
+#[serde(rename_all = "camelCase")]
+pub struct CoinInfo {
+    pub coin: String,
+    pub deposit_all_enable: bool,
+    #[serde(with = "string_or_float")]
+    pub free: f64,
+    #[serde(with = "string_or_float")]
+    pub freeze: f64,
+    #[serde(with = "string_or_float")]
+    pub ipoable: f64,
+    #[serde(with = "string_or_float")]
+    pub ipoing: f64,
+    pub is_legal_money: bool,
+    #[serde(with = "string_or_float")]
+    pub locked: f64,
+    pub name: String,
+    pub network_list: Vec<Network>,
+    #[serde(with = "string_or_float")]
+    pub storage: f64,
+    pub trading: bool,
+    pub withdraw_all_enable: bool,
+    #[serde(with = "string_or_float")]
+    pub withdrawing: f64,
+}
+
+/// Part of the Savings API get all coins response
+#[derive(Debug, Serialize, Deserialize, Clone)]
+#[serde(rename_all = "camelCase")]
+pub struct Network {
+    pub address_regex: String,
+    pub coin: String,
+    /// shown only when "depositEnable" is false.
+    pub deposit_desc: Option<String>,
+    pub deposit_enable: bool,
+    pub is_default: bool,
+    pub memo_regex: String,
+    /// min number for balance confirmation
+    pub min_confirm: u32,
+    pub name: String,
+    pub network: String,
+    pub reset_address_status: bool,
+    pub special_tips: Option<String>,
+    /// confirmation number for balance unlock
+    pub un_lock_confirm: u32,
+    /// shown only when "withdrawEnable" is false.
+    pub withdraw_desc: Option<String>,
+    pub withdraw_enable: bool,
+    #[serde(with = "string_or_float")]
+    pub withdraw_fee: f64,
+    #[serde(with = "string_or_float")]
+    pub withdraw_min: f64,
+    // pub insert_time: Option<u64>, //commented out for now, because they are not inside the actual response (only the api doc example)
+    // pub update_time: Option<u64>,
+    pub withdraw_integer_multiple: Option<String>,
+}
+
+#[derive(Debug, Serialize, Deserialize, Clone)]
+#[serde(rename_all = "camelCase")]
+pub struct AssetDetail {
+    #[serde(with = "string_or_float")]
+    pub min_withdraw_amount: f64,
+    /// false if ALL of networks' are false
+    pub deposit_status: bool,
+    #[serde(with = "string_or_float")]
+    pub withdraw_fee: f64,
+    /// false if ALL of networks' are false
+    pub withdraw_status: bool,
+    /// reason
+    pub deposit_tip: Option<String>,
+}
+
+#[derive(Debug, Serialize, Deserialize, Clone)]
+pub struct DepositAddress {
+    pub address: String,
+    pub coin: String,
+    pub tag: String,
+    pub url: String,
+}
+
 pub(crate) mod string_or_float {
     use std::fmt;
 
@@ -797,7 +878,13 @@ pub(crate) mod string_or_float {
         }
 
         match StringOrFloat::deserialize(deserializer)? {
-            StringOrFloat::String(s) => s.parse().map_err(de::Error::custom),
+            StringOrFloat::String(s) => {
+                if s == "INF" {
+                    Ok(f64::INFINITY)
+                } else {
+                    s.parse().map_err(de::Error::custom)
+                }
+            },
             StringOrFloat::Float(i) => Ok(i),
         }
     }
